Crate pkgar

Crate pkgar 

Modules

ext
Extention traits for base types defined in pkgar-core.

Structs

MergedTransaction
A struct that helps merging multiple transaction into one. All transactions are validated to make sure there’s no two action holding the same target file.
PackageFile
PackageHead
Transaction
A struct that holds many atomic file operation
TransactionConflict

Enums

Action
Individual atomic file operation
Error

Functions

create
create_with_flags
extract
list
remove
split
verify