Modules
- ext
- Extention traits for base types defined in
pkgar-core.
Structs
- Merged
Transaction - A struct that helps merging multiple transaction into one. All transactions are validated to make sure there’s no two action holding the same target file.
- Package
File - Package
Head - Transaction
- A struct that holds many atomic file operation
- Transaction
Conflict